Re: [PATCH] diff: release blobs after generating textual diff.
- From
Robin Rosenberg <robin.rosenberg.lists@dewire.com>
- Date
- May 6, 2007, 21:36 UTC
- Message-ID
- <200705062336.28201.robin.rosenberg.lists@dewire.com>
- In-Reply-To
- <alpine.LFD.0.99.0705061301190.24220@xanadu.home>
söndag 06 maj 2007 skrev Nicolas Pitre:
Show 19 quoted lines
> On Sun, 6 May 2007, Junio C Hamano wrote: > > > This reduces the memory pressure when dealing with many paths. > > > > An unscientific test of running "diff-tree --stat --summary -M" > > between v2.6.19 and v2.6.20-rc1 in the linux kernel repository > > indicates that the number of minor faults are reduced by 2/3 > > (153k vs 49k). > > > > Signed-off-by: Junio C Hamano <junkio@cox.net> > > --- > > > > * This is still a WIP, not in the sense that it breaks anything > > (it doesn't seem to), but in the sense that it is not known > > if it is useful in general and would make that much of a > > difference with a project much larger than the kernel. > > This can only be good. People are really starting to use Git with > gigantic repos on limited memory hardware.
This did wonders on the usually unreasonable diffs on huge repos. The openoffice diff mentioned in the openoffice thread went from 6 to ~3 minutes, and most importantly the computer was perfectly usable meanwhile. Git memory usage dropped from 1,7GB to 400MB.
A more reasonable test diffing against a recent branch , master vs v33M4-patches, in the eclipse repo some of you have didn't gain much in performance, but memory usage dropped from 700MB to a peak just under 400MB, which makes a huge difference in responsiveness for the other applications that I have, since they were not swapped out during the diff.
-- robin